@@ -202,7 +202,6 @@ class Gentic(object):
             verbose=1,
             is_save=1,
             rootid=0,
-            session=0,
             standard_score=2,  # None代表 根据tournament_size保留种群  standard_score保留种群
             out_dir='result',
             backup_cycle=0,  # 后备数据周期，主要用于在时间序列上的问题
@@ -241,19 +240,16 @@ class Gentic(object):
         self._rootid = int(
             time.time() * 1000000 +
             datetime.datetime.now().microsecond) if rootid == 0 else rootid
-        self._session = int(
-            time.time() * 1000000 +
-            datetime.datetime.now().microsecond) if session == 0 else session
         self._save_model = self.save_model if save_model is None else save_model
         self._con_time = 0
         self._best_fitness = 0
 
-    def save_model(self, gen, rootid, session, best_programs):
+    def save_model(self, gen, rootid, best_programs):
         result_list = [{
             'transform': program.transform(),
             'fitness': program._raw_fitness
         } for program in best_programs]
-        out_dir = os.path.join(self._out_dir, str(session))
+        out_dir = os.path.join(self._out_dir, str(rootid))
         if not os.path.exists(out_dir):
             os.makedirs(out_dir)
         filename = os.path.join(out_dir, 'ultron_' + str(gen) + '.pkl')
@@ -426,7 +422,7 @@ class Gentic(object):
 
             #保存每代信息
             if self._is_save:
-                self._save_model(gen, self._rootid, self._session,
+                self._save_model(gen, self._rootid,
                                  self._run_details['best_programs'][-1],
                                  self._custom_params)
 
