@@ -7,6 +7,7 @@ from ultron.sentry.api.Analysis import AVG
 from ultron.sentry.api.Analysis import EMA
 from ultron.sentry.api.Analysis import MACD
 from ultron.sentry.api.Analysis import RSI
+from ultron.sentry.api.Analysis import MARETURNLog
 from ultron.sentry.api.Analysis import MCORR
 from ultron.sentry.api.Analysis import MA
 from ultron.sentry.api.Analysis import MADecay
@@ -15,6 +16,10 @@ from ultron.sentry.api.Analysis import MARGMAX
 from ultron.sentry.api.Analysis import MMIN
 from ultron.sentry.api.Analysis import MARGMIN
 from ultron.sentry.api.Analysis import MRANK
+from ultron.sentry.api.Analysis import ADDED
+from ultron.sentry.api.Analysis import SUBBED
+from ultron.sentry.api.Analysis import MUL
+from ultron.sentry.api.Analysis import DIV
 from ultron.sentry.api.Analysis import MAXIMUM
 from ultron.sentry.api.Analysis import MINIMUM
 from ultron.sentry.api.Analysis import MQUANTILE
@@ -43,6 +48,8 @@ from ultron.sentry.api.Analysis import NORMINV
 from ultron.sentry.api.Analysis import CEIL
 from ultron.sentry.api.Analysis import FLOOR
 from ultron.sentry.api.Analysis import ROUND
+from ultron.sentry.api.Analysis import SIGMOID
+from ultron.sentry.api.Analysis import TANH
 from ultron.sentry.api.Analysis import SHIFT
 from ultron.sentry.api.Analysis import DELTA
 from ultron.sentry.api.Analysis import IIF
@@ -62,63 +69,16 @@ from ultron.sentry.api.Analysis import CSRes
 
 from ultron.sentry.Utilities.Asserts import pyFinAssert
 
-
-__all__ = ["transform",
-           "SIGN",
-           "SeriesValues",
-           "AVG",
-           "EMA",
-           "MACD",
-           "RSI",
-           "MCORR",
-           "MA",
-           "MADecay",
-           "MMAX",
-           "MARGMAX",
-           "MMIN",
-           "MARGMIN",
-           "MRANK",
-           "MAXIMUM",
-           "MINIMUM",
-           "MQUANTILE",
-           "MALLTRUE",
-           "MANYTRUE",
-           "MSUM",
-           "MVARIANCE",
-           "MSTD",
-           "MNPOSITIVE",
-           "MAPOSITIVE",
-           "CURRENT",
-           "LAST",
-           "SQRT",
-           "DIFF",
-           "RETURNSimple",
-           "RETURNLog",
-           "EXP",
-           "LOG",
-           "POW",
-           "ABS",
-           "ACOS",
-           "ACOSH",
-           "ASIN",
-           "ASINH",
-           "NORMINV",
-           "CEIL",
-           "FLOOR",
-           "ROUND",
-           "SHIFT",
-           "DELTA",
-           "IIF",
-           "INDUSTRY",
-           "CSRank",
-           "CSTopN",
-           "CSBottomN",
-           "CSTopNQuantile",
-           "CSBottomNQuantile",
-           "CSMean",
-           "CSMeanAdjusted",
-           "CSQuantiles",
-           "CSZScore",
-           "CSFillNA",
-           "CSRes",
-           "pyFinAssert"]
+__all__ = [
+    "transform", "SIGN", "SeriesValues", "AVG", "EMA", "MACD", "RSI",
+    "MARETURNLog", "MCORR", "MA", "MADecay", "MMAX", "MARGMAX", "MMIN",
+    "MARGMIN", "MRANK", "MAXIMUM", "MINIMUM", "MQUANTILE", "MALLTRUE",
+    "MANYTRUE", "MSUM", "MVARIANCE", "ADDED", "SUBBED", "MUL", "DIV", "MSTD",
+    "MNPOSITIVE", "MAPOSITIVE", "CURRENT", "LAST", "SQRT", "DIFF", "SIGMOD",
+    "TANH", "RETURNSimple", "RETURNLog", "EXP", "LOG", "POW", "ABS", "ACOS",
+    "ACOSH", "ASIN", "ASINH", "NORMINV", "CEIL", "FLOOR", "ROUND", "SIGMOID",
+    "TANH", "SHIFT", "DELTA", "IIF", "INDUSTRY", "CSRank", "CSTopN",
+    "CSBottomN", "CSTopNQuantile", "CSBottomNQuantile", "CSMean",
+    "CSMeanAdjusted", "CSQuantiles", "CSZScore", "CSFillNA", "CSRes",
+    "pyFinAssert"
+]
